summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorMiod Vallat <miod@cvs.openbsd.org>2009-07-17 07:14:01 +0000
committerMiod Vallat <miod@cvs.openbsd.org>2009-07-17 07:14:01 +0000
commit4833bca3fb910a919a5b0c74c42b383e99971df2 (patch)
tree6db24a7726be976fa78204e34a865a94636aee29 /sys
parent2299013ddd9e6ce7302b396f8b7a78d2e6af5cb7 (diff)
Revert a not-thoroughly tested change part of a larger work in progress diff,
which crept in the previous commit.
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/sgi/xbow/xbridge.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/arch/sgi/xbow/xbridge.c b/sys/arch/sgi/xbow/xbridge.c
index 139e40ad6de..da6ba7e3e63 100644
--- a/sys/arch/sgi/xbow/xbridge.c
+++ b/sys/arch/sgi/xbow/xbridge.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: xbridge.c,v 1.35 2009/07/16 21:02:58 miod Exp $ */
+/* $OpenBSD: xbridge.c,v 1.36 2009/07/17 07:14:00 miod Exp $ */
/*
* Copyright (c) 2008, 2009 Miodrag Vallat.
@@ -674,11 +674,11 @@ xbridge_intr_establish(void *cookie, pci_intr_handle_t ih, int level,
if (new) {
/*
* XXX The interrupt dispatcher is always registered
* XXX at IPL_TTY, in case the interrupt will be shared
* XXX between devices of different levels.
*/
if (xbow_intr_establish(xbridge_intr_handler, xi, intrsrc,
- IPL_TTY, NULL)) {
+ IPL_BIO, NULL)) {
printf("%s: unable to register interrupt handler\n",
sc->sc_dev.dv_xname);
return NULL;
@@ -674,11 +674,11 @@ xbridge_intr_establish(void *cookie, pci_intr_handle_t ih, int level,
/*
* XXX The interrupt dispatcher is always registered
- * XXX at IPL_TTY, in case the interrupt will be shared
+ * XXX at IPL_BIO, in case the interrupt will be shared
* XXX between devices of different levels.
*/